@@ -35,7 +35,7 @@ class DataReport(abstract_tab.Tab):
         self,
         endpoints: endpoints.Endpoints,
         dataset_id: str,
-        title: str,
+        title: Optional[str] = None,
         name: Optional[str] = None,
         colour: Optional[str] = None,
         config: Optional[Dict[str, Any]] = None,
@@ -57,7 +57,7 @@ class DataReport(abstract_tab.Tab):
             assert colour in colour_values, f"Colour must one of {colour_values}"
 
         self.config["colour"] = colour
-        self.config["configuration"]["title"] = title
+        self.config["configuration"]["title"] = self.ID if title is None else title
         self.config["name"] = name
 
     @classmethod
